@@ -3,13 +3,13 @@ from bx import download as dl
 
 
 class ANTSCommand(Command):
-    """ANTS
+    """ANTS - Advanced Normalization Tools
 
     Available subcommands:
-     files:\t\tdownload all `ASHS` outputs (segmentation maps, volumes, everything...)
-     snapshot:\t\tdownload a snapshot from the `ASHS` pipeline
-     report:\t\tdownload the validation report issued by `ASHSValidator`
-     tests:\t\tcreates an Excel table with all automatic tests outcomes from `ASHSValidator`
+     files:\t\tdownload all `ANTS` outputs
+     snapshot:\t\tdownload a snapshot from the `ANTS` pipeline
+     report:\t\tdownload the validation report issued by `ANTSValidator`
+     tests:\t\tcreates an Excel table with all automatic tests outcomes from `ANTSValidator`
 
     Usage:
      bx ants <subcommand> <resource_id>
@@ -29,7 +29,7 @@ class ANTSCommand(Command):
         if subcommand in ['files', 'report', 'snapshot']:
             self.run_id(id, dl.download, resource_name=self.resource_name,
                         validator=self.validator, destdir=self.destdir,
-                        overwrite=self.overwrite, subcommand=subcommand)
+                        subcommand=subcommand)
 
         elif subcommand == 'tests':
             version = ['*', '0390c55f']
@@ -38,4 +38,4 @@ class ANTSCommand(Command):
             df = self.run_id(id, val.validation_scores,
                              validator=self.validator,
                              version=version, max_rows=25)
-            self.to_excel(id, df)
+            self.to_excel(df)
