@@ -27,4 +27,4 @@ class ArchivingCommand(Command):
             df = self.run_id(id, val.validation_scores,
                              validator=self.resource_name,
                              version=version, max_rows=25)
-            self.to_excel(id, df)
+            self.to_excel(df)
