@@ -5,12 +5,11 @@ import os
 
 
 class Command(object):
-    def __init__(self, command, args, xnat_instance, destdir, overwrite):
+    def __init__(self, command, args, xnat_instance, destdir):
         self.command = command
         self.args = args
         self.xnat = xnat_instance
         self.destdir = destdir
-        self.overwrite = overwrite
 
     def run_id(self, id, func, **kwargs):
         from bx import xnat
@@ -30,9 +29,13 @@ class Command(object):
             experiments = xnat.collect_experiments(self.xnat, id)
         return func(self.xnat, experiments, **kwargs)
 
-    def to_excel(self, id, df):
+    def to_excel(self, df):
         dt = datetime.today().strftime('%Y%m%d_%H%M%S')
-        fn = 'bx_%s_%s_%s.xlsx' % (self.command, id, dt)
+        args = ''
+        if len(self.args) != 0:
+            args = '_' + '_'.join(self.args)
+
+        fn = 'bx_%s%s_%s.xlsx' % (self.command, args, dt)
         fp = op.join(self.destdir, fn)
         log.info('Saving it in %s' % fp)
         df.to_excel(fp)
