@@ -2,7 +2,7 @@ from bx.command import Command
 
 
 class IDCommand(Command):
-    """Returns subject/session labels along with parent project.
+    """Return generic information like subject/session labels, parent project.
 
     Usage:
      bx id <resource_id>
@@ -19,7 +19,7 @@ class IDCommand(Command):
         if len(df) == 1:
             print(df.iloc[0])
         else:
-            self.to_excel(id, df)
+            self.to_excel(df)
 
 
 def get_id_table(x, experiments):
