@@ -2,11 +2,9 @@ import logging as log
 
 
 def check_xnat_item(x, a):
-    projects = [e.label() for e in list(x.select.projects())]
-    experiments = []
-    for p in projects:
-        exp = x.array.experiments(project_id=p).data
-        experiments.extend([e['ID'] for e in exp])
+    experiments = x.array.experiments()
+    projects = [e['project'] for e in experiments]
+    experiments = [e['ID'] for e in x.array.experiments()]
 
     result = -1
     if a in projects:
